MomoPayResponse class

Constructors

MomoPayResponse({required String status, required String message, Data? data})
MomoPayResponse.fromJson(Map<String, dynamic> json)
factory

Properties

data Data?
The data returned from the request. can be null if something happened internally when making the request. Eg the client has poor network etc
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
This is the message that flutterwave returns when you iniate a paymnet request
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
This is the staus of the transaction you have just made. Can be "success" or "failed"
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited